@@ -738,7 +738,7 @@ passdlg_set_auth_state (PasswordDialog *pdialog, gboolean state)
 		gtk_widget_grab_focus (GTK_WIDGET (pdialog->new_password));
 		
 		/* Set open lock image */
-		gtk_image_set_from_file (GTK_IMAGE (pdialog->dialog_image), GNOMECC_DATA_DIR "/pixmaps/gnome-about-me-lock-open.png");
+		gtk_image_set_from_file (GTK_IMAGE (pdialog->dialog_image), GNOMECC_PIXMAP_DIR "/gnome-about-me-lock-open.png");
 	} else {
 		/* Not authenticated state */
 		
@@ -746,7 +746,7 @@ passdlg_set_auth_state (PasswordDialog *pdialog, gboolean state)
 		gtk_widget_grab_focus (GTK_WIDGET (pdialog->current_password));
 		
 		/* Set closed lock image */
-		gtk_image_set_from_file (GTK_IMAGE (pdialog->dialog_image), GNOMECC_DATA_DIR "/pixmaps/gnome-about-me-lock.png");
+		gtk_image_set_from_file (GTK_IMAGE (pdialog->dialog_image), GNOMECC_PIXMAP_DIR "/gnome-about-me-lock.png");
 	}
 }
 
@@ -784,10 +784,11 @@ passdlg_spawn_passwd (PasswordDialog *pdialog)
 	
 	/* Spawn backend */
 	if (!spawn_passwd (pdialog, &error)) {
-		details = g_strdup_printf (_("Unable to launch /usr/bin/passwd: %s"), error->message);
+		details = g_strdup_printf (_("Unable to launch %s: %s"),
+					   "/usr/bin/passwd", error->message);
 		
 		passdlg_error_dialog (_("Unable to launch backend"),
-							  _("A system error has occurred"),
+						  _("A system error has occurred"),
 							  details);
 		
 		g_free (details);
@@ -832,7 +833,6 @@ passdlg_validate_passwords (PasswordDialog *pdialog)
 	GladeXML		*dialog;
 	const gchar	*new_password, *retyped_password;
 	glong			nlen, rlen;
-	gboolean 		valid = FALSE;
 	
 	dialog = pdialog->xml;
 	
@@ -983,7 +983,7 @@ passdlg_init (PasswordDialog *pdialog, GtkWindow *parent)
 	GtkAccelGroup	*group;
 	
 	/* Initialize dialog */
-	dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/gnome-about-me.glade", "change-password", NULL);
+	dialog = glade_xml_new (GNOMECC_GLADE_DIR "/gnome-about-me.glade", "change-password", NULL);
 	pdialog->xml = dialog;
 	
 	wpassdlg = WID ("change-password");
