@@ -160,7 +160,8 @@ web_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     GnomeDAWebItem *item;
     GConfChangeSet *cs;
     GError *error = NULL;
-
+    char *http_cmd;
+    
     gtk_combo_box_get_active_iter (combo, &iter);
     path = gtk_tree_model_get_path (gtk_combo_box_get_model (combo), &iter);
     current_index = gtk_tree_path_get_indices (path)[0];
@@ -200,8 +201,9 @@ web_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
 	is_custom_active = TRUE;
     }
 
-    gtk_entry_set_text (GTK_ENTRY (capplet->web_browser_command_entry),
-			gconf_client_get_string (capplet->gconf, DEFAULT_APPS_KEY_HTTP_EXEC, NULL));
+    http_cmd = gconf_client_get_string (capplet->gconf, DEFAULT_APPS_KEY_HTTP_EXEC, NULL);
+    gtk_entry_set_text (GTK_ENTRY (capplet->web_browser_command_entry), http_cmd);
+    g_free (http_cmd);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->web_browser_terminal_checkbutton),
 				  gconf_client_get_bool (capplet->gconf, DEFAULT_APPS_KEY_HTTP_NEEDS_TERM, NULL));
 
@@ -213,7 +215,7 @@ web_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     gtk_widget_set_sensitive (capplet->web_browser_command_label, is_custom_active);
     gtk_widget_set_sensitive (capplet->web_browser_terminal_checkbutton, is_custom_active);
 }
-
+	
 static void
 mail_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
 {
@@ -224,7 +226,8 @@ mail_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     GnomeDAMailItem *item;
     GConfChangeSet *cs;
     GError *error = NULL;
-
+    char *mailer_cmd;
+    
     gtk_combo_box_get_active_iter (combo, &iter);
     path = gtk_tree_model_get_path (gtk_combo_box_get_model (combo), &iter);
     current_index = gtk_tree_path_get_indices (path)[0];
@@ -253,8 +256,9 @@ mail_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
 	is_custom_active = TRUE;
     }
 
-    gtk_entry_set_text (GTK_ENTRY (capplet->mail_reader_command_entry),
-			gconf_client_get_string (capplet->gconf, DEFAULT_APPS_KEY_MAILER_EXEC, NULL));
+    mailer_cmd = gconf_client_get_string (capplet->gconf, DEFAULT_APPS_KEY_MAILER_EXEC, NULL);
+    gtk_entry_set_text (GTK_ENTRY (capplet->mail_reader_command_entry), mailer_cmd);
+    g_free (mailer_cmd);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->mail_reader_terminal_checkbutton),
 				  gconf_client_get_bool (capplet->gconf, DEFAULT_APPS_KEY_MAILER_NEEDS_TERM, NULL));
 
@@ -273,6 +277,7 @@ terminal_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     GnomeDATermItem *item;
     GConfChangeSet *cs;
     GError *error = NULL;
+    char *terminal_cmd, *terminal_cmd_arg;
 
     gtk_combo_box_get_active_iter (combo, &iter);
     path = gtk_tree_model_get_path (gtk_combo_box_get_model (combo), &iter);
@@ -301,11 +306,12 @@ terminal_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     else {
 	is_custom_active = TRUE;
     }
-
-    gtk_entry_set_text (GTK_ENTRY (capplet->terminal_command_entry),
-			gconf_client_get_string (capplet->gconf, DEFAULT_APPS_KEY_TERMINAL_EXEC, NULL));
-    gtk_entry_set_text (GTK_ENTRY (capplet->terminal_exec_flag_entry),
-			gconf_client_get_string (capplet->gconf, DEFAULT_APPS_KEY_TERMINAL_EXEC_ARG, NULL));
+    terminal_cmd = gconf_client_get_string (capplet->gconf, DEFAULT_APPS_KEY_TERMINAL_EXEC, NULL);
+    terminal_cmd_arg = gconf_client_get_string (capplet->gconf, DEFAULT_APPS_KEY_TERMINAL_EXEC_ARG, NULL);
+    gtk_entry_set_text (GTK_ENTRY (capplet->terminal_command_entry), terminal_cmd);
+    gtk_entry_set_text (GTK_ENTRY (capplet->terminal_exec_flag_entry), terminal_cmd_arg);
+    g_free (terminal_cmd);
+    g_free (terminal_cmd_arg);
 
     gtk_editable_set_editable (GTK_EDITABLE (capplet->terminal_command_entry), is_custom_active);
     gtk_widget_set_sensitive (capplet->terminal_command_label, is_custom_active);
@@ -554,6 +560,7 @@ web_gconf_changed_cb (GConfClient *client, guint id, GConfEntry *entry, GnomeDAC
     GConfValue *value;
     GConfChangeSet *cs;
     GError *error = NULL;
+    GList *list_entry;
 
     g_return_if_fail (gconf_entry_get_key (entry) != NULL);
 
@@ -561,6 +568,7 @@ web_gconf_changed_cb (GConfClient *client, guint id, GConfEntry *entry, GnomeDAC
 	return;
 
     if (strcmp (entry->key, DEFAULT_APPS_KEY_HTTP_EXEC) == 0) {
+	gchar* short_browser;
 	web_browser_update_combo_box (capplet, gconf_value_get_string (value));
 	web_browser_update_radio_buttons (capplet, gconf_value_get_string (value));
 
@@ -569,6 +577,21 @@ web_gconf_changed_cb (GConfClient *client, guint id, GConfEntry *entry, GnomeDAC
 	gconf_change_set_set (cs, DEFAULT_APPS_KEY_HTTPS_EXEC, value);
 	gconf_change_set_set (cs, DEFAULT_APPS_KEY_UNKNOWN_EXEC, value);
 	gconf_change_set_set (cs, DEFAULT_APPS_KEY_ABOUT_EXEC, value);
+	short_browser = g_strndup(gconf_value_get_string(value),
+				  strstr(gconf_value_get_string(value), " ") -
+				  gconf_value_get_string(value));
+	gconf_change_set_set_string (cs, DEFAULT_APPS_KEY_BROWSER_EXEC, short_browser);
+	g_free(short_browser);
+
+	list_entry = g_list_find_custom (capplet->web_browsers,
+					 gconf_value_get_string (value),
+					 (GCompareFunc) web_item_comp);
+
+	if (list_entry) {
+	    GnomeDAWebItem *item = (GnomeDAWebItem *) list_entry->data;
+
+	    gconf_change_set_set_bool (cs, DEFAULT_APPS_KEY_BROWSER_NREMOTE, item->netscape_remote);
+	}
 
 	gconf_client_commit_change_set (capplet->gconf, cs, TRUE, &error);
 
@@ -590,6 +613,7 @@ web_gconf_changed_cb (GConfClient *client, guint id, GConfEntry *entry, GnomeDAC
 	gconf_change_set_set (cs, DEFAULT_APPS_KEY_HTTPS_NEEDS_TERM, value);
 	gconf_change_set_set (cs, DEFAULT_APPS_KEY_UNKNOWN_NEEDS_TERM, value);
 	gconf_change_set_set (cs, DEFAULT_APPS_KEY_ABOUT_NEEDS_TERM, value);
+	gconf_change_set_set (cs, DEFAULT_APPS_KEY_BROWSER_NEEDS_TERM, value);
 
 	gconf_client_commit_change_set (capplet->gconf, cs, TRUE, &error);
 
@@ -664,7 +688,6 @@ fill_combo_box (GtkIconTheme *theme, GtkComboBox *combo_box, GList *app_list)
     GtkCellRenderer *renderer;
     GtkTreeIter iter;
     GdkPixbuf *pixbuf;
-    gchar *label;
 
     if (theme == NULL) {
 	theme = gtk_icon_theme_get_default ();
@@ -696,19 +719,17 @@ fill_combo_box (GtkIconTheme *theme, GtkComboBox *combo_box, GList *app_list)
 	item = (GnomeDAItem *) entry->data;
 
 	pixbuf = gtk_icon_theme_load_icon (theme, item->icon_name, 22, 0, NULL);
-	label = g_strdup (item->name);
 
 	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 			    PIXBUF_COL, pixbuf,
-			    TEXT_COL, label,
+			    TEXT_COL, item->name,
 			    -1);
 
 	item->icon_path = gtk_tree_model_get_string_from_iter (model, &iter);
 
 	if (pixbuf)
 	    g_object_unref (pixbuf);
-	g_free (label);
     }
 
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
@@ -778,26 +799,50 @@ show_dialog (GnomeDACapplet *capplet)
 
     /* update ui to gconf content */
     value = gconf_client_get (capplet->gconf, DEFAULT_APPS_KEY_HTTP_EXEC, NULL);
-    web_browser_update_combo_box (capplet, gconf_value_get_string (value));
-    web_browser_update_radio_buttons (capplet, gconf_value_get_string (value));
+    if (value)
+    {
+	web_browser_update_combo_box (capplet, gconf_value_get_string (value));
+	web_browser_update_radio_buttons (capplet, gconf_value_get_string (value));
+	gconf_value_free (value);
+    }
 
     value = gconf_client_get (capplet->gconf, DEFAULT_APPS_KEY_HTTP_NEEDS_TERM, NULL);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->web_browser_terminal_checkbutton),
-				  gconf_value_get_bool (value));
+    if (value)
+    {
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->web_browser_terminal_checkbutton),
+				      gconf_value_get_bool (value));
+	gconf_value_free (value);
+    }
 
     value = gconf_client_get (capplet->gconf, DEFAULT_APPS_KEY_MAILER_EXEC, NULL);
-    mail_reader_update_combo_box (capplet, gconf_value_get_string (value));
+    if (value)
+    {
+	mail_reader_update_combo_box (capplet, gconf_value_get_string (value));
+	gconf_value_free (value);
+    }
 
     value = gconf_client_get (capplet->gconf, DEFAULT_APPS_KEY_MAILER_NEEDS_TERM, NULL);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->mail_reader_terminal_checkbutton),
-				  gconf_value_get_bool (value));
+    if (value)
+    {
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->mail_reader_terminal_checkbutton),
+				      gconf_value_get_bool (value));
+	gconf_value_free (value);
+    }
 
-    value = gconf_client_get (capplet->gconf, DEFAULT_APPS_KEY_TERMINAL_EXEC, NULL);
-    terminal_update_combo_box (capplet, gconf_value_get_string (value));
+    if (value)
+    {
+	value = gconf_client_get (capplet->gconf, DEFAULT_APPS_KEY_TERMINAL_EXEC, NULL);
+	terminal_update_combo_box (capplet, gconf_value_get_string (value));
+	gconf_value_free (value);
+    }
 
     value = gconf_client_get (capplet->gconf, DEFAULT_APPS_KEY_TERMINAL_EXEC_ARG, NULL);
-    gtk_entry_set_text (GTK_ENTRY (capplet->terminal_exec_flag_entry),
-			gconf_value_get_string (value));
+    if (value)
+    {
+	gtk_entry_set_text (GTK_ENTRY (capplet->terminal_exec_flag_entry),
+			    gconf_value_get_string (value));
+	gconf_value_free (value);
+    }
 
     g_signal_connect (capplet->web_combo_box, "changed", G_CALLBACK (web_combo_changed_cb), capplet);
     g_signal_connect (capplet->mail_combo_box, "changed", G_CALLBACK (mail_combo_changed_cb), capplet);
@@ -829,21 +874,22 @@ show_dialog (GnomeDACapplet *capplet)
 int
 main (int argc, char **argv)
 {
+    GnomeProgram *program;
     GnomeDACapplet *capplet;
 
-    capplet = g_new0 (GnomeDACapplet, 1);
-
 #ifdef ENABLE_NLS
     bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     textdomain (GETTEXT_PACKAGE);
 #endif
 
-    gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
-			GNOME_PARAM_NONE);
+    program = gnome_program_init ("gnome-default-applications-properties",
+    				  VERSION, LIBGNOMEUI_MODULE, argc, argv,
+				  GNOME_PARAM_NONE);
 
     glade_init ();
 
+    capplet = g_new0 (GnomeDACapplet, 1);
     capplet->gconf = gconf_client_get_default ();
 
     gconf_client_add_dir (capplet->gconf, "/desktop/gnome/applications/browser", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
@@ -867,7 +913,9 @@ main (int argc, char **argv)
     gtk_main ();
 
     g_object_unref (capplet->gconf);
-    g_object_unref (capplet->xml);
+    
+    gnome_da_xml_free (capplet);
+    g_object_unref (program);
 
     return 0;
 }
