@@ -43,13 +43,13 @@
 void handle_static_action_clicked (Tile * tile, TileEvent * event, gpointer data);
 static GSList *get_actions_list ();
 
-#define CONTROL_CENTER_PREFIX             "/desktop/gnome/applications/main-menu/cc_"
+#define CONTROL_CENTER_PREFIX             "/apps/control-center/cc_"
 #define CONTROL_CENTER_ACTIONS_LIST_KEY   (CONTROL_CENTER_PREFIX  "actions_list")
 #define CONTROL_CENTER_ACTIONS_SEPARATOR  ";"
 #define EXIT_SHELL_ON_STATIC_ACTION       "exit_shell_on_static_action"
 
 static GSList *
-get_actions_list ()
+get_actions_list (void)
 {
 	GSList *l;
 	GSList *key_list;
@@ -92,15 +92,22 @@ void
 handle_static_action_clicked (Tile * tile, TileEvent * event, gpointer data)
 {
 	gchar *temp;
-
 	AppShellData *app_data = (AppShellData *) data;
 	GnomeDesktopItem *item =
 		(GnomeDesktopItem *) g_object_get_data (G_OBJECT (tile), APP_ACTION_KEY);
+
+	if (event->type == TILE_EVENT_ACTIVATED_DOUBLE_CLICK)
+		return;
 	open_desktop_item_exec (item);
 
 	temp = g_strdup_printf("%s%s", app_data->gconf_prefix, EXIT_SHELL_ON_STATIC_ACTION);
 	if (get_slab_gconf_bool(temp))
-		gtk_main_quit ();
+	{
+		if (app_data->exit_on_close)
+			gtk_main_quit ();
+		else
+			hide_shell (app_data);
+	}
 	g_free (temp);
 }
 
@@ -126,7 +133,7 @@ main (int argc, char *argv[])
 		{
 			printf ("Usage - gnome-control-center [-h]\n");
 			printf ("Options: -h : hide on start\n");
-			printf ("\tUseful if you want to autostart the control-center singleton so it can get all it's slow loading done\n");
+			printf ("\tUseful if you want to autostart the control-center singleton so it can get all its slow loading done\n");
 			exit (1);
 		}
 		hidden = TRUE;
@@ -134,7 +141,7 @@ main (int argc, char *argv[])
 
 	startup_id = g_strdup (g_getenv (DESKTOP_STARTUP_ID));
 	program = gnome_program_init ("GNOME Control Center", "0.1", LIBGNOMEUI_MODULE,
-				      argc, argv, NULL, NULL);
+		argc, argv, NULL, NULL);
 
 	if (apss_already_running (argc, argv, &bonobo_app, "GNOME-NLD-ControlCenter", startup_id))
 	{
@@ -144,8 +151,8 @@ main (int argc, char *argv[])
 		exit (1);
 	}
 
-	app_data = appshelldata_new (
-		"preferences.menu", NULL, CONTROL_CENTER_PREFIX, GTK_ICON_SIZE_DIALOG, TRUE);
+	app_data = appshelldata_new ("gnomecc.menu", NULL, CONTROL_CENTER_PREFIX,
+		GTK_ICON_SIZE_DND, FALSE, TRUE);
 	generate_categories (app_data);
 
 	actions = get_actions_list ();
